@@ -13,10 +13,10 @@ use File::Basename;
 use File::Temp qw(tempfile);
 use File::stat;
 use File::Spec;
-use IPC::Cmd;
+use IPC::Cmd qw(run);
 use Carp;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 my %sections = (
     global => 1,
@@ -231,12 +231,14 @@ sub save {
 				   DIR => dirname($self->filename));
     $self->write($fh, @wrargs);
     close($fh);
-
     if (my $cmd = $self->lint) {
-	my ($ok, $err, undef, undef, $errbuf) =
-	    IPC::Cmd->run(command => "$cmd $tempfile");
+	my ($ok, $err, $full, $outbuf, $errbuf) =
+	    run(command => "$cmd $tempfile");
 	unless ($ok) {
-	    croak "Syntax check failed: $errbuf\n";
+	    if ($errbuf && @$errbuf) {
+		croak "Syntax check failed: ".join("\n", @$errbuf)."\n";
+	    }
+	    croak $err;
 	}
     }
     return 1 if $dry_run;
